import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:flutter_pluggy_connect/flutter_pluggy_connect.dart';

class _HomePageState extends State<HomePage> {
  bool _showPluggyConnect = false;

  void _togglePluggyConnect() {
    setState(() {
      _showPluggyConnect = !_showPluggyConnect;
    });
  }

  @override
  Widget build(BuildContext context) {
    if (!_showPluggyConnect) {
      return Scaffold(
        appBar: AppBar(title: const Text('PluggyConnect Example App')),
        body: Center(
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              const Text(
                'Welcome to Pluggy!',
                style: TextStyle(fontSize: 24),
              ),
              const SizedBox(height: 16),
              ElevatedButton(
                onPressed: _togglePluggyConnect,
                child: const Text('Open PluggyConnect'),
              ),
            ],
          ),
        ),
      );
    }

    return PluggyConnect(
      includeSandbox: true,
      onSuccess: (data) {
        print('Success');
        print(jsonEncode(data));
      },
      onClose: () {
        print('Closed');
        _togglePluggyConnect();
      },
      onError: (error) {
        print('Error');
        print(jsonEncode(error));
      },
      onOpen: () {
        print('Opened');
      },
      onEvent: (payload) {
        print('Event');
        print(jsonEncode(payload));
      },
      connectToken: '<connect token>',
    );
  }
}

class HomePage extends StatefulWidget {
  @override
  _HomePageState createState() => _HomePageState();
}

void main() {
  runApp(
    MaterialApp(
        home: Scaffold(
            appBar: AppBar(backgroundColor: Colors.black, toolbarHeight: 1),
            body: HomePage())),
  );
}
